pygeoip

Package pygeoip |
[frames] | no frames]

# Package pygeoip

source code

Pure Python GeoIP API

Authors:
  Jennifer Ennis <zaylea@gmail.com>, William Tisäter <william@defunct.cc>

License: Copyright(C) 2004 MaxMind LLC

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this program. If not, see <http://www.gnu.org/licenses/lgpl.txt>.

Submodules
pygeoip.const: Constants for the database parser pygeoip.timezone: Time zone data and lookup function pygeoip.util: Utility function for address translation

Classes
| GeoIPError
| GeoIP

Variables
| STANDARD = `0`
| MMAP_CACHE = `8`
| MEMORY_CACHE = `1`
| ENCODING = ``'``iso-8859-1``'``
| __package__ = ``'``pygeoip``'``